@@ -4,16 +4,16 @@
 #include "include/globals.h"
 #include "include/matrix.h"
 
-/* fast implementation of conditional least squares with just the intercept. */
+/* conditional least squares with just the intercept and complete data. */
 static void c_cls0(double *y, int *z, int nrow, int ncond, double *fitted,
     double *resid, double *beta, double *sd) {
 
 int i = 0, *nz = NULL;
 long double *means = NULL;
 
-  /* the matrix of regression coefficients contains the conditional mean given
-   * each configuration; estimate in a single pass (set to NaN if there a no
-   * observations for a particular observation). */
+  /* the matrix of regression coefficients contains the conditional mean for
+   * each configuration of the discrete variables, set to NaN if there are no
+   * observations for a particular configuration). */
   means = Calloc1D(ncond, sizeof(long double));
   nz = Calloc1D(ncond, sizeof(int));
 
@@ -33,15 +33,20 @@ long double *means = NULL;
 
   }/*FOR*/
 
+  /* the only regression coefficient is the intercept, which is the mean of the
+   * response; the standard error is the standard deviation of the response. */
   if (beta)
-    for (i  = 0; i < ncond; i++)
+    for (i = 0; i < ncond; i++)
       beta[i] = means[i];
+
   if (fitted)
-    for (i  = 0; i < nrow; i++)
+    for (i = 0; i < nrow; i++)
       fitted[i] = means[z[i] - 1];
+
   if (resid)
-    for (i  = 0; i < nrow; i++)
+    for (i = 0; i < nrow; i++)
       resid[i] = y[i] - means[z[i] - 1];
+
   if (sd)
     c_cgsd(y, z, nz, nrow, ncond, 1, means, sd);
 
@@ -50,8 +55,7 @@ long double *means = NULL;
 
 }/*C_CLS0*/
 
-/* fast implementation of conditional least squares with one regression
- * coefficient. */
+/* conditional least squares with one regression coefficient and complete data. */
 static void c_cls1(double **x, double *y, int *z, int nrow, int ncond,
     double *fitted, double *resid, double *beta, double *sd) {
 
@@ -91,8 +95,8 @@ long double *mean_y = NULL, *mean_x = NULL, *var_x = NULL, *cov = NULL, *ssr = N
   }/*FOR*/
 
   /* the regression coefficients are computed using the closed form estimators
-   * for simple regression (set to NaN if there a no observations for a
-   * particular observation). */
+   * for simple regression (set to NaN if there are no observations for a
+   * particular configuration of the discrete variables). */
   for (i = 0; i < ncond; i++) {
 
     if (nz[i] == 0) {
@@ -111,33 +115,52 @@ long double *mean_y = NULL, *mean_x = NULL, *var_x = NULL, *cov = NULL, *ssr = N
 
   if (beta)
     memcpy(beta, cc, 2 * ncond * sizeof(double));
+
   if (fitted)
-    for (i  = 0; i < nrow; i++)
+    for (i = 0; i < nrow; i++)
       fitted[i] = cc[(z[i] - 1) * 2] + x[0][i] * cc[(z[i] - 1) * 2 + 1];
+
   if (resid) {
 
-    if (fitted)
-      for (i  = 0; i < nrow; i++)
+    if (fitted) {
+
+      for (i = 0; i < nrow; i++)
         resid[i] = y[i] - fitted[i];
-    else
-      for (i  = 0; i < nrow; i++)
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
         resid[i] = y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1];
 
+    }/*ELSE*/
+
   }/*THEN*/
+
   if (sd) {
 
     ssr = Calloc1D(ncond, sizeof(long double));
 
-    if (resid)
-      for (i  = 0; i < nrow; i++)
+    if (resid) {
+
+      for (i = 0; i < nrow; i++)
         ssr[z[i] - 1] += resid[i] * resid[i];
-    else if (fitted)
-      for (i  = 0; i < nrow; i++)
+
+    }/*THEN*/
+    else if (fitted) {
+
+      for (i = 0; i < nrow; i++)
         ssr[z[i] - 1] += (y[i] - fitted[i]) * (y[i] - fitted[i]);
-    else
-      for (i  = 0; i < nrow; i++)
-        ssr[z[i] - 1] += (y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1]) *
-               (y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1]);
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
+        ssr[z[i] - 1] +=
+          (y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1]) *
+          (y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1]);
+
+    }/*ELSE*/
 
     for (i = 0; i < ncond; i++) {
 
@@ -163,8 +186,7 @@ long double *mean_y = NULL, *mean_x = NULL, *var_x = NULL, *cov = NULL, *ssr = N
 
 }/*C_CLS1*/
 
-/* fast implementation of conditional least squares with two regression
- * coefficients. */
+/* conditional least squares with two regression coefficients and complete data. */
 static void c_cls2(double **x, double *y, int *z, int nrow, int ncond,
     double *fitted, double *resid, double *beta, double *sd) {
 
@@ -269,39 +291,60 @@ long double den = 0, *ssr = NULL;
 
   if (beta)
     memcpy(beta, cc, 3 * ncond * sizeof(double));
-  if (fitted)
-    for (i  = 0; i < nrow; i++)
+
+  if (fitted) {
+
+    for (i = 0; i < nrow; i++)
       fitted[i] = cc[(z[i] - 1) * 3] + x[0][i] * cc[(z[i] - 1) * 3 + 1]
                     + x[1][i] * cc[(z[i] - 1) * 3 + 2];
+
+  }/*THEN*/
+
   if (resid) {
 
-    if (fitted)
-      for (i  = 0; i < nrow; i++)
+    if (fitted) {
+
+      for (i = 0; i < nrow; i++)
         resid[i] = y[i] - fitted[i];
-    else
-      for (i  = 0; i < nrow; i++)
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
         resid[i] = y[i] - cc[(z[i] - 1) * 3] - x[0][i] * cc[(z[i] - 1) * 3 + 1]
                      - x[1][i] * cc[(z[i] - 1) * 3 + 2];
 
+    }/*ELSE*/
+
   }/*THEN*/
+
   if (sd) {
 
     ssr = Calloc1D(ncond, sizeof(long double));
 
-    if (resid)
-      for (i  = 0; i < nrow; i++)
+    if (resid) {
+
+      for (i = 0; i < nrow; i++)
         ssr[z[i] - 1] += resid[i] * resid[i];
-    else if (fitted)
-      for (i  = 0; i < nrow; i++)
+
+    }/*THEN*/
+    else if (fitted) {
+
+      for (i = 0; i < nrow; i++)
         ssr[z[i] - 1] += (y[i] - fitted[i]) * (y[i] - fitted[i]);
-    else
-      for (i  = 0; i < nrow; i++)
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
         ssr[z[i] - 1] +=
           (y[i] - cc[(z[i] - 1) * 3] - x[0][i] * cc[(z[i] - 1) * 3 + 1]
                 - x[1][i] * cc[(z[i] - 1) * 3 + 2]) *
           (y[i] - cc[(z[i] - 1) * 3] - x[0][i] * cc[(z[i] - 1) * 3 + 1]
                 - x[1][i] * cc[(z[i] - 1) * 3 + 2]);
 
+    }/*ELSE*/
+
     for (i = 0; i < ncond; i++) {
 
       if (nz[i] == 0)
@@ -327,7 +370,7 @@ long double den = 0, *ssr = NULL;
 
 }/*C_CLS2*/
 
-/* general implementation of conditional least squares. */
+/* general implementation of conditional least squares with complete data. */
 void c_clsp(double **x, double *y, int *z, int nrow, int ncol, int ncond,
     double *fitted, double *resid, double *beta, double *sd) {
 
@@ -397,7 +440,7 @@ double **qr_matrix = NULL, **yy = NULL, *ff = NULL, *rr = NULL;
 
     }/*THEN*/
 
-    /* gcc cannot optimize the copying of fitted values and residuals if
+    /* gcc does not optimize the copying of fitted values and residuals if
      * implemented as a loop with lots of conditionals, so treat each case
      * separately. */
     if (!fitted && !resid) {
@@ -472,7 +515,7 @@ double **qr_matrix = NULL, **yy = NULL, *ff = NULL, *rr = NULL;
 
 }/*C_CLSP*/
 
-/* fast implementation of conditional least squares with just the intercept. */
+/* conditional least squares with just the intercept and missing data. */
 static void c_cls0_with_missing(double *y, int *z, int nrow, int ncond,
     double *fitted, double *resid, double *beta, double *sd) {
 
@@ -480,19 +523,18 @@ int i = 0, *nz = NULL;
 long double *means = NULL, *ssr = NULL;
 
   /* the matrix of regression coefficients contains the conditional mean given
-   * each configuration; estimate in a single pass (set to NaN if there a no
-   * observations for a particular observation). */
+   * each configuration of the discrete parents; estimate in a single pass (set
+   * to NaN if there are no observations for a particular configuration). */
   means = Calloc1D(ncond, sizeof(long double));
   nz = Calloc1D(ncond, sizeof(int));
 
   for (i = 0; i < nrow; i++) {
 
-    if (!ISNAN(y[i]) && (z[i] != NA_INTEGER)) {
+    if ((z[i] == NA_INTEGER) || ISNAN(y[i]))
+      continue;
 
-      means[z[i] - 1] += y[i];
-      nz[z[i] - 1]++;
-
-    }/*THEN*/
+    means[z[i] - 1] += y[i];
+    nz[z[i] - 1]++;
 
   }/*FOR*/
 
@@ -505,15 +547,32 @@ long double *means = NULL, *ssr = NULL;
 
   }/*FOR*/
 
-  if (beta)
+  if (beta) {
+
     for (i = 0; i < ncond; i++)
       beta[i] = means[i];
-  if (fitted)
+
+  }/*THEN*/
+
+  if (fitted) {
+
     for (i = 0; i < nrow; i++)
-      fitted[i] = (z[i] != NA_INTEGER) && !ISNAN(y[i]) ? means[z[i] - 1] : NA_REAL;
-  if (resid)
+      if ((z[i] == NA_INTEGER) || ISNAN(y[i]))
+        fitted[i] = NA_REAL;
+      else
+        fitted[i] = means[z[i] - 1];
+  }/*THEN*/
+
+  if (resid) {
+
     for (i = 0; i < nrow; i++)
-      resid[i] = (z[i] != NA_INTEGER) && !ISNAN(y[i]) ? y[i] - means[z[i] - 1] : NA_REAL;
+      if ((z[i] == NA_INTEGER) || ISNAN(y[i]))
+        resid[i] = NA_REAL;
+      else
+        resid[i] = y[i] - means[z[i] - 1];
+
+  }/*THEN*/
+
   if (sd) {
 
     ssr = Calloc1D(ncond, sizeof(long double));
@@ -560,7 +619,361 @@ long double *means = NULL, *ssr = NULL;
 
 }/*C_CLS0_WITH_MISSING*/
 
-/* general implementation of conditional least squares. */
+/* conditional least squares with one regression coefficient and missing data. */
+static void c_cls1_with_missing(double **x, double *y, int *z, int nrow,
+    int ncond, double *fitted, double *resid, double *beta, double *sd) {
+
+int i = 0, *nz = NULL;
+double *cc = NULL;
+long double *mean_y = NULL, *mean_x = NULL, *var_x = NULL, *cov = NULL, *ssr = NULL;
+
+  /* first pass: compute the conditional means of y and x. */
+  mean_y = Calloc1D(ncond, sizeof(long double));
+  mean_x = Calloc1D(ncond, sizeof(long double));
+  var_x = Calloc1D(ncond, sizeof(long double));
+  cov = Calloc1D(ncond, sizeof(long double));
+  nz = Calloc1D(ncond, sizeof(int));
+  cc = Calloc1D(2 * ncond, sizeof(double));
+
+  for (i = 0; i < nrow; i++) {
+
+    if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]))
+      continue;
+
+    mean_y[z[i] - 1] += y[i];
+    mean_x[z[i] - 1] += x[0][i];
+    nz[z[i] - 1]++;
+
+  }/*FOR*/
+
+  for (i = 0; i < ncond; i++) {
+
+    mean_y[i] /= nz[i];
+    mean_x[i] /= nz[i];
+
+  }/*FOR*/
+
+  /* second pass: compute the covariance between x and y and the variance of x. */
+  for (i = 0; i < nrow; i++) {
+
+    if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]))
+      continue;
+
+    var_x[z[i] - 1] += (x[0][i] - mean_x[z[i] - 1]) * (x[0][i] - mean_x[z[i] - 1]);
+    cov[z[i] - 1] += (y[i] - mean_y[z[i] - 1]) * (x[0][i] - mean_x[z[i] - 1]);
+
+  }/*FOR*/
+
+  /* the regression coefficients are computed using the closed form estimators
+   * for simple regression (set to NaN if there are no observations for a
+   * particular configuration of the discrete variables). */
+  for (i = 0; i < ncond; i++) {
+
+    if (nz[i] == 0) {
+
+      cc[i * 2] = cc[i * 2 + 1] = R_NaN;
+
+    }/*THEN*/
+    else {
+
+      cc[i * 2 + 1] = (fabsl(var_x[i]) < MACHINE_TOL) ? 0 : cov[i] / var_x[i];
+      cc[i * 2] = mean_y[i] - mean_x[i] * cc[i * 2 + 1];
+
+    }/*ELSE*/
+
+  }/*FOR*/
+
+  if (beta)
+    memcpy(beta, cc, 2 * ncond * sizeof(double));
+
+  if (fitted) {
+
+    for (i = 0; i < nrow; i++)
+      if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]))
+        fitted[i] = NA_REAL;
+      else
+        fitted[i] = cc[(z[i] - 1) * 2] + x[0][i] * cc[(z[i] - 1) * 2 + 1];
+
+  }/*THEN*/
+
+  if (resid) {
+
+    if (fitted) {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]))
+          resid[i] = NA_REAL;
+        else
+          resid[i] = y[i] - fitted[i];
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]))
+          resid[i] = NA_REAL;
+        else
+          resid[i] = y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1];
+
+    }/*ELSE*/
+
+  }/*THEN*/
+
+  if (sd) {
+
+    ssr = Calloc1D(ncond, sizeof(long double));
+
+    if (resid) {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] != NA_INTEGER) && (!ISNAN(y[i])) && (!ISNAN(x[0][i])))
+          ssr[z[i] - 1] += resid[i] * resid[i];
+
+    }/*THEN*/
+    else if (fitted) {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] != NA_INTEGER) && (!ISNAN(y[i])) && (!ISNAN(x[0][i])))
+          ssr[z[i] - 1] += (y[i] - fitted[i]) * (y[i] - fitted[i]);
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] != NA_INTEGER) && (!ISNAN(y[i])) && (!ISNAN(x[0][i])))
+          ssr[z[i] - 1] +=
+            (y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1]) *
+            (y[i] - cc[(z[i] - 1) * 2] - x[0][i] * cc[(z[i] - 1) * 2 + 1]);
+
+    }/*ELSE*/
+
+    for (i = 0; i < ncond; i++) {
+
+      if (nz[i] == 0)
+        sd[i] = R_NaN;
+      else if (nz[i] <= 2)
+        sd[i] = 0;
+      else
+        sd[i] = sqrt(ssr[i] / (nz[i] - 2));
+
+    }/*FOR*/
+
+    Free1D(ssr);
+
+  }/*THEN*/
+
+  Free1D(cc);
+  Free1D(mean_y);
+  Free1D(mean_x);
+  Free1D(var_x);
+  Free1D(cov);
+  Free1D(nz);
+
+}/*C_CLS1_WITH_MISSING*/
+
+/* conditional least squares with two regression coefficients and missing data. */
+static void c_cls2_with_missing(double **x, double *y, int *z, int nrow,
+    int ncond, double *fitted, double *resid, double *beta, double *sd) {
+
+int i = 0, *nz = NULL, singular1 = FALSE, singular2 = FALSE;
+double *cc = NULL;
+long double *mean_y = NULL, *mean_x1 = NULL, *mean_x2 = NULL;
+long double **var = NULL, **cov = NULL;
+long double den = 0, *ssr = NULL;
+
+  /* first pass: compute the conditional means of y and x1. */
+  mean_y = Calloc1D(ncond, sizeof(long double));
+  mean_x1 = Calloc1D(ncond, sizeof(long double));
+  mean_x2 = Calloc1D(ncond, sizeof(long double));
+  var = (long double **) Calloc2D(ncond, 3, sizeof(long double));
+  cov = (long double **) Calloc2D(ncond, 3, sizeof(long double));
+  nz = Calloc1D(ncond, sizeof(int));
+  cc = Calloc1D(3 * ncond, sizeof(double));
+
+  for (i = 0; i < nrow; i++) {
+
+    if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]) || ISNAN(x[1][i]))
+      continue;
+
+    mean_y[z[i] - 1] += y[i];
+    mean_x1[z[i] - 1] += x[0][i];
+    mean_x2[z[i] - 1] += x[1][i];
+    nz[z[i] - 1]++;
+
+  }/*FOR*/
+
+  for (i = 0; i < ncond; i++) {
+
+    mean_y[i] /= nz[i];
+    mean_x1[i] /= nz[i];
+    mean_x2[i] /= nz[i];
+
+  }/*FOR*/
+
+  /* second pass: compute the variances of (y, x1, x2); and the covariances of
+   * ((y, x1), (y, x2), (x1, x2)). */
+  for (i = 0; i < nrow; i++) {
+
+    if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]) || ISNAN(x[1][i]))
+      continue;
+
+    var[z[i] - 1][0] += (y[i] - mean_y[z[i] - 1]) * (y[i] - mean_y[z[i] - 1]);
+    var[z[i] - 1][1] += (x[0][i] - mean_x1[z[i] - 1]) * (x[0][i] - mean_x1[z[i] - 1]);
+    var[z[i] - 1][2] += (x[1][i] - mean_x2[z[i] - 1]) * (x[1][i] - mean_x2[z[i] - 1]);
+    cov[z[i] - 1][0] += (y[i] - mean_y[z[i] - 1]) * (x[0][i] - mean_x1[z[i] - 1]);
+    cov[z[i] - 1][1] += (y[i] - mean_y[z[i] - 1]) * (x[1][i] - mean_x2[z[i] - 1]);
+    cov[z[i] - 1][2] += (x[0][i] - mean_x1[z[i] - 1]) * (x[1][i] - mean_x2[z[i] - 1]);
+
+  }/*FOR*/
+
+  /* the regression coefficients are computed using the closed form estimates
+   * for the two-variable regression, which are effectively the same as the
+   * corresponding partial correlation estimates. */
+  for (i = 0; i < ncond; i++) {
+
+    if (nz[i] == 0) {
+
+      cc[i * 3] = cc[i * 3 + 1] = cc[i * 3 + 2] = R_NaN;
+
+    }/*THEN*/
+    else {
+
+      /* there are three possible collinear configurations:
+       *   1) the first variable is constant and collinear with the response;
+       *   2) the second variable is constant and collinear with the response;
+       *   3) the two variables are collinear with each other. */
+      singular1 = (fabsl(var[i][1]) < MACHINE_TOL);
+      singular2 = (fabsl(var[i][2]) < MACHINE_TOL) ||
+                  (fabsl(cov[i][2]) / sqrt(var[i][1] * var[i][2]) > 1 - MACHINE_TOL);
+
+      if (singular1 && !singular2) {
+
+        cc[i * 3 + 1] = 0;
+        cc[i * 3 + 2] = cov[i][1] / var[i][2];
+        cc[i * 3] = mean_y[i] - mean_x2[i] * cc[i * 3 + 2];
+
+      }/*THEN*/
+      else if (!singular1 && singular2) {
+
+        cc[i * 3 + 1] = cov[i][0] / var[i][1];
+        cc[i * 3 + 2] = 0;
+        cc[i * 3] = mean_y[i] - mean_x1[i] * cc[i * 3 + 1];
+
+      }/*THEN*/
+      else if (singular1 && singular2) {
+
+       cc[i * 3 + 1] = cc[i * 3 + 2] = 0;
+       cc[i * 3] = mean_y[i];
+
+      }/*THEN*/
+      else {
+
+        den = (var[i][1] * var[i][2] - cov[i][2] * cov[i][2]);
+
+        cc[i * 3 + 1] = (var[i][2] * cov[i][0] - cov[i][2] * cov[i][1]) / den;
+        cc[i * 3 + 2] = (var[i][1] * cov[i][1] - cov[i][2] * cov[i][0]) / den;
+        cc[i * 3] = mean_y[i] - mean_x1[i] * cc[i * 3 + 1] - mean_x2[i] * cc[i * 3 + 2];
+
+      }/*ELSE*/
+
+    }/*ELSE*/
+
+  }/*FOR*/
+
+  if (beta)
+    memcpy(beta, cc, 3 * ncond * sizeof(double));
+
+  if (fitted) {
+
+    for (i = 0; i < nrow; i++)
+      if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]) || ISNAN(x[1][i]))
+        fitted[i] = NA_REAL;
+      else
+        fitted[i] = cc[(z[i] - 1) * 3] + x[0][i] * cc[(z[i] - 1) * 3 + 1]
+                      + x[1][i] * cc[(z[i] - 1) * 3 + 2];
+
+  }/*THEN*/
+
+  if (resid) {
+
+    if (fitted) {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]) || ISNAN(x[1][i]))
+          resid[i] = NA_REAL;
+        else
+          resid[i] = y[i] - fitted[i];
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] == NA_INTEGER) || ISNAN(y[i]) || ISNAN(x[0][i]) || ISNAN(x[1][i]))
+          resid[i] = NA_REAL;
+        else
+          resid[i] = y[i] - cc[(z[i] - 1) * 3] - x[0][i] * cc[(z[i] - 1) * 3 + 1]
+                       - x[1][i] * cc[(z[i] - 1) * 3 + 2];
+
+    }/*ELSE*/
+
+  }/*THEN*/
+
+  if (sd) {
+
+    ssr = Calloc1D(ncond, sizeof(long double));
+
+    if (resid) {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] != NA_INTEGER) && !ISNAN(y[i]) && !ISNAN(x[0][i]) && !ISNAN(x[1][i]))
+          ssr[z[i] - 1] += resid[i] * resid[i];
+
+    }/*THEN*/
+    else if (fitted) {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] != NA_INTEGER) && !ISNAN(y[i]) && !ISNAN(x[0][i]) && !ISNAN(x[1][i]))
+          ssr[z[i] - 1] += (y[i] - fitted[i]) * (y[i] - fitted[i]);
+
+    }/*THEN*/
+    else {
+
+      for (i = 0; i < nrow; i++)
+        if ((z[i] != NA_INTEGER) && !ISNAN(y[i]) && !ISNAN(x[0][i]) && !ISNAN(x[1][i]))
+          ssr[z[i] - 1] +=
+            (y[i] - cc[(z[i] - 1) * 3] - x[0][i] * cc[(z[i] - 1) * 3 + 1]
+                  - x[1][i] * cc[(z[i] - 1) * 3 + 2]) *
+            (y[i] - cc[(z[i] - 1) * 3] - x[0][i] * cc[(z[i] - 1) * 3 + 1]
+                  - x[1][i] * cc[(z[i] - 1) * 3 + 2]);
+
+    }/*ELSE*/
+
+    for (i = 0; i < ncond; i++) {
+
+      if (nz[i] == 0)
+        sd[i] = R_NaN;
+      else if (nz[i] <= 3)
+        sd[i] = 0;
+      else
+        sd[i] = sqrt(ssr[i] / (nz[i] - 3));
+
+    }/*FOR*/
+
+    Free1D(ssr);
+
+  }/*THEN*/
+
+  Free1D(mean_y);
+  Free1D(mean_x1);
+  Free1D(mean_x2);
+  Free2D(var, ncond);
+  Free2D(cov, ncond);
+  Free1D(nz);
+  Free1D(cc);
+
+}/*C_CLS2_WITH_MISSING*/
+
+/* general implementation of conditional least squares with missing data. */
 void c_clsp_with_missing(double **x, double *y, int *z, int nrow, int ncol,
     int ncond, double *fitted, double *resid, double *beta, double *sd) {
 
@@ -650,7 +1063,7 @@ int check = FALSE, ncomplete = 0, *complete = NULL, **zid = NULL;
 
     }/*THEN*/
 
-    /* gcc cannot optimize the copying of fitted values and residuals if
+    /* gcc does not optimize the copying of fitted values and residuals if
      * implemented as a loop with lots of conditionals, so treat each case
      * separately. */
     if (!fitted && !resid) {
@@ -779,6 +1192,16 @@ void c_cls(double **x, double *y, int *z, int nrow, int ncol, int ncond,
 
       c_cls0_with_missing(y, z, nrow, ncond, fitted, resid, beta, sd);
 
+    }/*THEN*/
+    else if (ncol == 1) {
+
+      c_cls1_with_missing(x, y, z, nrow, ncond, fitted, resid, beta, sd);
+
+    }/*THEN*/
+    else if (ncol == 2) {
+
+      c_cls2_with_missing(x, y, z, nrow, ncond, fitted, resid, beta, sd);
+
     }/*THEN*/
     else {
 
