@@ -1,6 +1,6 @@
 #include "include/rcore.h"
 #include "include/sets.h"
-#include "include/dataframe.h"
+#include "include/data.frame.h"
 #include "include/scores.h"
 
 /* posterior Dirichlet probability (covers BD and K2 scores). */
@@ -148,7 +148,7 @@ double imaginary = 0, alpha = 0, res = 0;
 
 /* Dirichlet posterior probabilities (covers BD and K2 scores). */
 double dirichlet_node(SEXP target, SEXP x, SEXP data, SEXP iss, int per_cell,
-    SEXP prior, SEXP beta, SEXP experimental, int sparse, int debuglevel) {
+    SEXP prior, SEXP beta, SEXP experimental, int sparse, bool debugging) {
 
 char *t = (char *)CHAR(STRING_ELT(target, 0));
 double prob = 0, prior_prob = 0;
@@ -160,11 +160,11 @@ SEXP nodes, node_t, data_t, exp_data, parents, parent_vars, config;
   /* get the parents of the node. */
   parents = getListElement(node_t, "parents");
   /* extract the node's column from the data frame. */
-  data_t = c_dataframe_column(data, target, TRUE, FALSE);
+  PROTECT(data_t = c_dataframe_column(data, target, TRUE, FALSE));
   /* extract the list of eperimental data. */
-  exp_data = c_dataframe_column(experimental, target, TRUE, FALSE);
+  PROTECT(exp_data = c_dataframe_column(experimental, target, TRUE, FALSE));
   /* compute the prior probability component for the node. */
-  prior_prob = graph_prior_prob(prior, target, beta, nodes, debuglevel);
+  prior_prob = graph_prior_prob(prior, target, beta, nodes, debugging);
 
   if (length(parents) == 0) {
 
@@ -183,7 +183,7 @@ SEXP nodes, node_t, data_t, exp_data, parents, parent_vars, config;
 
   }/*ELSE*/
 
-  if (debuglevel > 0) {
+  if (debugging) {
 
     Rprintf("  > (log)prior probability is %lf.\n", prior_prob);
     Rprintf("  > (log)posterior density is %lf.\n", prob);
@@ -193,6 +193,8 @@ SEXP nodes, node_t, data_t, exp_data, parents, parent_vars, config;
   /* add the (log)prior to the marginal (log)likelihood to get the (log)posterior. */
   prob += prior_prob;
 
+  UNPROTECT(2);
+
   return prob;
 
 }/*DIRICHLET_NODE*/
