@@ -5,8 +5,11 @@ SEXP BN_NodesSymbol;
 SEXP BN_ProbSymbol;
 SEXP BN_MethodSymbol;
 SEXP BN_WeightsSymbol;
+SEXP BN_DsepsetSymbol;
 SEXP TRUESEXP, FALSESEXP;
 
+double *regret_table;
+
 SEXP onLoad() {
 
   /* initialize symbols in .onLoad(), to do that only once. */
@@ -15,6 +18,7 @@ SEXP onLoad() {
   BN_ProbSymbol = install("prob");
   BN_MethodSymbol = install("method");
   BN_WeightsSymbol = install("weights");
+  BN_DsepsetSymbol = install("dsep.set");
   TRUESEXP = ScalarLogical(TRUE);
   R_PreserveObject(TRUESEXP);
   FALSESEXP = ScalarLogical(FALSE);
